"""
Azure Data Explorer MCP Server
-----------------------------
A Model Context Protocol server implementation that provides tools and resources
for interacting with Azure Data Explorer (ADX).
"""

__version__ = "0.1.0"
